#!/bin/bash
# Copyright 2010 University of Chicago/Argonne National Laboratory
#
# Written by Neill Miller (neillm@mcs.anl.gov)

# Always clean first
rm -f libglobus_adq_client *.o *.a libglobus_adq.so* libglobus_adq-version

# use this line for debugging
#DEBUG="-DDEBUG"

# use this line for the release
DEBUG=""

# adjust this accordingly, or leave blank for system defaults
GSOAP_PATH=/usr/local/gsoap

if [ "x$GSOAP_PATH" = "x" ]; then
   GSOAP_PATH=/usr
fi

PWD=`pwd`

$GSOAP_PATH/bin/wsdl2h -c saml.wsdl

#-e 's/@//g' 
# replace all generated but known errors
cat saml.h | sed -e 's/    int                                  __sizeSubjectConfirmation/    \/\/int                                  __sizeSubjectConfirmation/g' -e 's/    struct ns2__SubjectConfirmationType\*  ns2__SubjectConfirmation/    \/\/struct ns2__SubjectConfirmationType\*  ns2__SubjectConfirmation/g' -e 's/    struct xsd__base64Binary             PGPKeyPacket/    \/\/struct xsd__base64Binary             PGPKeyPacket/g' -e 's/    struct xsd__base64Binary\*            PGPKeyPacket/    \/\/struct xsd__base64Binary\*            PGPKeyPacket/g' -e 's/    int                                  __size\s/    \/\/int                                  __size\s/g' -e 's/_XML                                \*__any/    \/\/_XML                                \*__any/g' > saml.h.tmp; mv saml.h.tmp saml.h

$GSOAP_PATH/bin/soapcpp2 -c saml.h -I$GSOAP_PATH/include

gcc ${DEBUG} -DWITH_NOEMPTYSTRUCT -DWITH_OPENSSL -I$GSOAP_PATH/include -fPIC -g -c *.c && \
gcc ${DEBUG} -DWITH_NOEMPTYSTRUCT -DWITH_OPENSSL -I$GSOAP_PATH/include -shared -Wl,-soname,libglobus_adq.so.0 -o libglobus_adq.so.0.0.0 libglobus_adq.o  soapClientLib.o  soapC.o  soapServerLib.o  stdsoap2.o -lc  && \
ln -s libglobus_adq.so.0.0.0 libglobus_adq.so && \
ln -s libglobus_adq.so.0.0.0 libglobus_adq.so.0 && \
LD_LIBRARY_PATH=$PWD gcc -o libglobus_adq_client libglobus_adq_client.c -lglobus_adq -L. -luuid -lssl && \
echo "" && \
echo "Build completed!  Run the client with \"LD_LIBRARY_PATH=$PWD ./libglobus_adq_client\""

echo "To install the library for use with Globus, copy globus_libadq.so* to $GLOBUS_LOCATION/lib"
echo "To install the test client for use with Globus, copy libglobus_adq_client to $GLOBUS_LOCATION/bin"

# generate version file
cat libglobus_adq_client.c | grep "define VERSION" | sed 's/\"//g' | awk '{print $3}' > libglobus_adq-version
VERSION=`cat libglobus_adq-version`

echo "This package has a version number of ${VERSION} stored in the file called libglobus_adq-version"
